@@ -18,6 +18,12 @@ if not settings.configured:
             'tests',
         ],
         MIDDLEWARE_CLASSES=[],
+        TEMPLATES=[
+            {
+                'BACKEND': 'django.template.backends.django.DjangoTemplates',
+                'APP_DIRS': True,
+            }
+        ],
     )
 
 
