@@ -3,18 +3,18 @@ from __future__ import absolute_import, unicode_literals
 import sys
 import warnings
 from unittest import TestCase as UnitTestCase
-from unittest import skipIf, skipUnless
 
 import django
 import mock
 from django.contrib.contenttypes.models import ContentType
 from django.core import serializers
-from django.core.exceptions import ImproperlyConfigured, ValidationError
+from django.core.exceptions import ValidationError
 from django.core.management import call_command
 from django.db import connection, models
 from django.test import RequestFactory, TestCase, TransactionTestCase
 from django.test.utils import override_settings
 from django.utils.encoding import force_text
+from django.views.generic.list import ListView
 
 from .forms import (CustomPKFoodForm, DirectCustomPKFoodForm, DirectFoodForm,
                     FoodForm, OfficialFoodForm)
@@ -24,13 +24,14 @@ from .models import (Article, Child, CustomManager, CustomPKFood,
                      DirectHousePet, DirectPet, Food, HousePet, Movie,
                      OfficialFood, OfficialHousePet, OfficialPet, OfficialTag,
                      OfficialThroughModel, Pet, Photo, TaggedCustomPK,
-                     TaggedCustomPKFood, TaggedFood)
+                     TaggedCustomPKFood, TaggedFood,
+                     UUIDFood, UUIDTag)
 
 from taggit.managers import TaggableManager, _TaggableManager
 from taggit.models import Tag, TaggedItem
-from taggit.views import tagged_object_list, TagListMixin
 from taggit.utils import (_related_model, _remote_field, edit_string_for_tags,
                           parse_tags)
+from taggit.views import TagListMixin, tagged_object_list
 
 
 class BaseTaggingTest(object):
@@ -110,6 +111,18 @@ class TagModelTestCase(BaseTaggingTransactionTestCase):
                 r"Expected <class 'django.db.models.base.ModelBase'> or str.")):
             apple.tags.add(1)
 
+    def test_gt(self):
+        high = self.tag_model.objects.create(name='high')
+        low = self.tag_model.objects.create(name='Low')
+        self.assertTrue(low > high)
+        self.assertFalse(high > low)
+
+    def test_lt(self):
+        high = self.tag_model.objects.create(name='high')
+        low = self.tag_model.objects.create(name='Low')
+        self.assertTrue(high < low)
+        self.assertFalse(low < high)
+
 
 class TagModelDirectTestCase(TagModelTestCase):
     food_model = DirectFood
@@ -598,13 +611,8 @@ class TaggableManagerTestCase(BaseTaggingTestCase):
             self.assertTrue(hasattr(field, 'rel'))
             self.assertTrue(hasattr(field.rel, 'to'))
 
-        # This API has changed in Django 1.8
-        # https://code.djangoproject.com/ticket/21414
-        if django.VERSION >= (1, 8):
-            self.assertEqual(self.food_model, field.model)
-            self.assertEqual(self.tag_model, _remote_field(field).model)
-        else:
-            self.assertEqual(self.food_model, field.related.model)
+        self.assertEqual(self.food_model, field.model)
+        self.assertEqual(self.tag_model, _remote_field(field).model)
 
     def test_names_method(self):
         apple = self.food_model.objects.create(name="apple")
@@ -656,6 +664,23 @@ class TaggableManagerTestCase(BaseTaggingTestCase):
         orange.tags.add('spain')
         self.assertEqual(list(orange.tags.all()), [spain])
 
+    @override_settings(TAGGIT_CASE_INSENSITIVE=True)
+    def test_with_case_insensitive_option_and_creation(self):
+        orange = self.food_model.objects.create(name="orange")
+        orange.tags.add('spain', 'Spain')
+        tag_names = list(orange.tags.names())
+        self.assertEqual(len(tag_names), 1, tag_names)
+
+    @override_settings(TAGGIT_CASE_INSENSITIVE=True)
+    def test_with_case_insensitive_option_new_and_old(self):
+        orange = self.food_model.objects.create(name="orange")
+        orange.tags.add('Spain')
+        tag_names = list(orange.tags.names())
+        self.assertEqual(len(tag_names), 1, tag_names)
+        orange.tags.add('spain', 'Valencia')
+        tag_names = sorted(orange.tags.names())
+        self.assertEqual(tag_names, ['Spain', 'Valencia'])
+
 
 class TaggableManagerDirectTestCase(TaggableManagerTestCase):
     food_model = DirectFood
@@ -961,9 +986,6 @@ class DjangoCheckTests(UnitTestCase):
         call_command('check', tag=['models'])
 
 
-from django.views.generic.list import ListView
-
-
 class FoodTagListView(TagListMixin, ListView):
     model = Food
 
@@ -998,3 +1020,7 @@ class TagListViewTests(BaseTaggingTestCase, TestCase):
         self.assertIn(self.apple, response.context_data['object_list'])
         self.assertNotIn(self.strawberry, response.context_data['object_list'])
 
+
+class TagUUIDModelTestCase(TagModelTestCase):
+    food_model = UUIDFood
+    tag_model = UUIDTag
